@@ -99,11 +99,11 @@ public:
   void AddPopup(OHotString *s, OXPopupMenu *popup, int ID = -2);
   void RemoveEntry(int ID, int type = MENU_ENTRY);
   void RemoveAllEntries();
-  void EnableEntry(int ID);
+  void EnableEntry(int ID, int enabled = True);
   void DisableEntry(int ID);
   int  IsEntryEnabled(int ID);
   void SetDefaultEntry(int ID);
-  void CheckEntry(int ID);
+  void CheckEntry(int ID, int checked = True);
   void UnCheckEntry(int ID);
   int  IsEntryChecked(int ID);
   void RCheckEntry(int ID, int IDfirst, int IDlast);
