@@ -222,7 +222,7 @@ int ODNDmanager::_IsDNDAware(Window win, Atom *typelist) {
   if ((count > 1) && typelist) {
     result = False;
     for (t = typelist; *t; t++) {
-      for (int j = 1; j < count; j++) {
+      for (int j = 1; j < (int) count; j++) {
         if (types[j] == *t) {
           result = True;
           break;
@@ -582,7 +582,7 @@ int ODNDmanager::_HandleDNDenter(Window src, long vers, Atom dataTypes[3]) {
 #endif
 
     a = (Atom *) data;
-    for (i = 0; i < count; i++)
+    for (i = 0; i < (int) count; i++)
       _draggerTypes[i+j] = a[i];
 
     _draggerTypes[i+j] = None;
