@@ -70,7 +70,7 @@ void OTileLayout::Layout() {
     ptr->frame->Move(xw, yw);
     x += max_osize.w + _sep;
 
-    if (x + max_osize.w > max_width) {
+    if (x + max_osize.w > (int) max_width) {
       x = _sep;
       y += max_osize.h + _sep + (_sep >> 1);
     }
