@@ -700,7 +700,7 @@ void OXColorPick::_InitImages() {
   // initialize _HSimage
 
   Visual *visual = DefaultVisual(GetDisplay(), _client->GetScreenNumber());
-  int ncolors = XDisplayCells(GetDisplay(), _client->GetScreenNumber());
+  //int ncolors = XDisplayCells(GetDisplay(), _client->GetScreenNumber());
 
   if (visual->c_class == TrueColor || visual->c_class == DirectColor) {
     OColor color;
@@ -744,7 +744,7 @@ void OXColorPick::_InitImages() {
 void OXColorPick::_SetSliderColor() {
 
   Visual *visual = DefaultVisual(GetDisplay(), _client->GetScreenNumber());
-  int ncolors = XDisplayCells(GetDisplay(), _client->GetScreenNumber());
+  //int ncolors = XDisplayCells(GetDisplay(), _client->GetScreenNumber());
 
   if (visual->c_class == TrueColor || visual->c_class == DirectColor) {
     OColor color;
