@@ -281,7 +281,7 @@ int OXFontDialog::HandleKey(XKeyEvent *event) {
 }
 
 int OXFontDialog::ProcessMessage(OMessage *msg) {
-  OListBoxMessage *lbmsg = (OListBoxMessage *) msg;
+  //OListBoxMessage *lbmsg = (OListBoxMessage *) msg;
   OWidgetMessage *wmsg = (OWidgetMessage *) msg;
 
   switch (msg->type) {
