@@ -781,7 +781,7 @@ void OHtmlLayoutContext::ClearObstacle(int mode) {
 // Return the next markup type  [OHtmlElement::NextMarkupType]
 
 int OXHtml::NextMarkupType(OHtmlElement *p) {
-  while (p = p->pNext)
+  while ((p = p->pNext))
     if (p->IsMarkup()) return p->type;
   return Html_Unknown;
 }
