@@ -40,7 +40,7 @@ const OXGC *OListViewItem::_dfnormGC;
 
 OListViewItem::OListViewItem(const OXListView *p, int id,
          const OPicture *bigpic, const OPicture *smallpic,
-         std::vector<OString *> names, int viewMode) :
+         std::vector<OString *> names, int viewMode, int fullLine) :
   OItem(p, id) {
 
   if (!_defaultFont) {
@@ -88,7 +88,7 @@ OListViewItem::OListViewItem(const OXListView *p, int id,
   _hilightGC = (OXGC *) _dfhilightGC;
   _normGC = (OXGC *) _dfnormGC;
 
-  SetViewMode(viewMode);
+  SetViewMode(viewMode, fullLine);
 }
 
 OListViewItem::~OListViewItem() {
@@ -120,7 +120,9 @@ void OListViewItem::SetFont(const OXFont *f) {
   }
 }
 
-void OListViewItem::SetViewMode(int viewMode) {
+void OListViewItem::SetViewMode(int viewMode, int fullLine) {
+
+  _fullRowSelect = fullLine;
 
   if (_viewMode == viewMode) return;
   _viewMode = viewMode;
@@ -165,6 +167,7 @@ ODimension OListViewItem::GetDefaultSize() const {
     case LV_DETAILS:
       size.w = isize.w + lsize.w + 4;
       size.h = max(isize.h, lsize.h);
+      if (_fullRowSelect && (_viewMode == LV_DETAILS)) size.w = _parent->GetVirtualSize().w;
       break;
   }
 
@@ -201,25 +204,32 @@ void OListViewItem::Draw(OXWindow *w, OPosition pos) {
 
   std::vector<SColumnData *> columnData = ((OXListView *)_parent)->GetColumns();
 
-  // displaying icon and name
-
-  if (pic)
-    pic->Draw(_client->GetDisplay(), w->GetId(), drawGC,
-              pos.x + _iconPos.x, pos.y + _iconPos.y);
-
+  // display icon and name
 
   if ((_viewMode == LV_DETAILS) && (columnData.size() > 0)) {
+    ODimension size = GetSize();
 
-    w->FillRectangle(rectGC, pos.x + _textPos.x, pos.y + _textPos.y,
-                     min(_tw, columnData[0]->width - _textPos.x - 2), _th + 1);
+    if (_fullRowSelect) {
+      w->FillRectangle(rectGC, -_parent->GetScrollPosition().x, pos.y, size.w, size.h);
+    } else {
+      w->FillRectangle(rectGC, pos.x + _textPos.x, pos.y + _textPos.y,
+                       min(_tw, columnData[0]->width - _textPos.x - 2), _th + 1);
+    }
 
     if (_focused && (_tw > 0)) {
-      w->DrawRectangle(_client->GetResourcePool()->GetDocumentBckgndGC()->GetGC(),
-                       pos.x + _textPos.x, pos.y + _textPos.y,
-                       min(_tw, columnData[0]->width - _textPos.x - 2)-1, _th);
-      w->DrawRectangle(_client->GetResourcePool()->GetFocusHiliteGC()->GetGC(),
-                       pos.x + _textPos.x, pos.y + _textPos.y,
-                       min(_tw, columnData[0]->width - _textPos.x - 2)-1, _th);
+      if (_fullRowSelect) {
+        w->DrawRectangle(_client->GetResourcePool()->GetDocumentBckgndGC()->GetGC(),
+                         -_parent->GetScrollPosition().x, pos.y, size.w-1, size.h-1);
+        w->DrawRectangle(_client->GetResourcePool()->GetFocusHiliteGC()->GetGC(),
+                         -_parent->GetScrollPosition().x, pos.y, size.w-1, size.h-1);
+      } else {
+        w->DrawRectangle(_client->GetResourcePool()->GetDocumentBckgndGC()->GetGC(),
+                         pos.x + _textPos.x, pos.y + _textPos.y,
+                         min(_tw, columnData[0]->width - _textPos.x - 2)-1, _th);
+        w->DrawRectangle(_client->GetResourcePool()->GetFocusHiliteGC()->GetGC(),
+                         pos.x + _textPos.x, pos.y + _textPos.y,
+                         min(_tw, columnData[0]->width - _textPos.x - 2)-1, _th);
+      }
     }
 
     DrawTruncated(w, drawGC, OPosition(pos.x + _textPos.x,
@@ -243,6 +253,10 @@ void OListViewItem::Draw(OXWindow *w, OPosition pos) {
                     pos.x + _textPos.x, pos.y + _textPos.y + _ta);
   }
 
+  if (pic)
+    pic->Draw(_client->GetDisplay(), w->GetId(), drawGC,
+              pos.x + _iconPos.x, pos.y + _iconPos.y);
+
   // as usual, DETAILS requires some more effort...
 
   if ((_viewMode == LV_DETAILS) && (columnData.size() > 0)) {
@@ -262,8 +276,8 @@ void OListViewItem::Draw(OXWindow *w, OPosition pos) {
         }
         if (tx < 2) tx = 2;
 
-        DrawTruncated(w, _normGC->GetGC(), OPosition(pos.x + tx,
-                                            pos.y + _textPos.y + _ta),
+        DrawTruncated(w, _fullRowSelect ? drawGC : _normGC->GetGC(),
+                      OPosition(pos.x + tx, pos.y + _textPos.y + _ta),
                      _names[j], columnData[i]->width - tx - 2);
       }
 
@@ -649,7 +663,10 @@ void OXListView::SetItemFont(const OXFont *f) {
   }
 }
 
-void OXListView::SetViewMode(int viewMode) {
+void OXListView::SetViewMode(int viewMode, int fullLine, int grid) {
+
+  _fullRowSelect = fullLine;
+  _gridLines = grid;
 
   if (_viewMode == viewMode) return;
 
@@ -660,10 +677,10 @@ void OXListView::SetViewMode(int viewMode) {
   if (_viewMode == LV_LARGE_ICONS)
     _itemSep = ODimension(8, 12);
   else
-    _itemSep = ODimension(2, 3);
+    _itemSep = ODimension(2, _gridLines ? 1 : 3);
 
   for (unsigned int i = 0; i < _items.size(); i++)
-    ((OListViewItem *) _items[i])->SetViewMode(_viewMode);
+    ((OListViewItem *) _items[i])->SetViewMode(_viewMode, _fullRowSelect);
 
   CalcMaxItemSize();
 
@@ -858,7 +875,7 @@ void OXListView::AddItem(OListViewItem *newItem) {
     }
   }
 
-  newItem->SetViewMode(_viewMode);
+  newItem->SetViewMode(_viewMode, _fullRowSelect);
   CalcMaxItemSize();
 
 //  Layout();
@@ -1051,10 +1068,16 @@ bool OXListView::ItemLayout() {
         currentPos.x = _itemSep.w;
         currentPos.y = _virtualSize.h;
         _items[i]->Move(currentPos);
+        _items[i]->Resize(_items[i]->GetDefaultSize());
         _virtualSize.h += _items[i]->GetDefaultSize().h + _itemSep.h;
       }
-      needRedraw = True;
       _virtualSize.w = GetMaxItemSize().w;
+      if (_fullRowSelect) {
+        for (i = 0; i < _items.size(); i++) {
+          _items[i]->Resize(_items[i]->GetDefaultSize());
+        }
+      }
+      needRedraw = True;
       break;
 
     default:
@@ -1097,10 +1120,29 @@ int OXListView::DrawRegion(OPosition coord, ODimension size, int clear) {
   if ((coord.y > _virtualSize.h) || (coord.x > _virtualSize.w)) return False;
 
   if (_viewMode == LV_DETAILS) {
-    for (unsigned int i = 0; i < _items.size(); ++i) {
-      if ((_items[i]->GetPosition().y < coord.y + size.h) &&
-          (_items[i]->GetPosition().y + _items[i]->GetSize().h > coord.y))
-        DrawItem(_items[i], coord, size);
+    if (_gridLines) {
+      for (unsigned int i = 0; i < _items.size(); ++i) {
+        int h = _items[i]->GetSize().h + _itemSep.h;
+        if ((_items[i]->GetPosition().y < coord.y + size.h) &&
+            (_items[i]->GetPosition().y + h > coord.y)) {
+          DrawItem(_items[i], coord, size);
+          int x = -_visibleStart.x;
+          int y = _items[i]->GetPosition().y - _visibleStart.y - 1;
+          int w = _virtualSize.w - 1;
+          _canvas->DrawRectangle(_bckgndGC, x, y, w, h);
+          for (unsigned int j = 0; j < _columnData.size() - 1; ++j) {
+            x += _columnData[j]->width;
+            _canvas->DrawLine(_bckgndGC, x+1, y, x+1, y + h);
+          }
+        }
+      }
+    } else {
+      for (unsigned int i = 0; i < _items.size(); ++i) {
+        if ((_items[i]->GetPosition().y < coord.y + size.h) &&
+            (_items[i]->GetPosition().y + _items[i]->GetSize().h > coord.y)) {
+          DrawItem(_items[i], coord, size);
+        }
+      }
     }
   }
 #endif
