@@ -1247,9 +1247,11 @@ void OXPopupMenu::SetDefaultEntry(int ID) {
 
 //---- enable/disable entry (disabled entries appear in a sunken relief)
 
-void OXPopupMenu::EnableEntry(int ID) {
+void OXPopupMenu::EnableEntry(int ID, int enabled) {
   OMenuEntry *ptr;
 
+  if (!enabled) { DisableEntry(ID); return; }
+
   for (ptr = _first; ptr != NULL; ptr = ptr->next)
     if (ptr->_entryID == ID) { ptr->_status |= MENU_ENABLE_MASK; break; }
 }
@@ -1272,9 +1274,11 @@ int OXPopupMenu::IsEntryEnabled(int ID) {
 
 //---- check/uncheck entry
 
-void OXPopupMenu::CheckEntry(int ID) {
+void OXPopupMenu::CheckEntry(int ID, int checked) {
   OMenuEntry *ptr;
 
+  if (!checked) { UnCheckEntry(ID); return; }
+
   for (ptr = _first; ptr != NULL; ptr = ptr->next)
     if (ptr->_entryID == ID) { ptr->_status |= MENU_CHECKED_MASK; break; }
 }
